import { lib } from './main1.js';

console.log(lib, lib.foo, lib.bar, lib.baz);
